JasonWoof Got questions, comments, patches, etc.? Contact Jason Woofenden
s/remain/remainder/
[dwm.git] / layout.c
index 9de26bc..259f489 100644 (file)
--- a/layout.c
+++ b/layout.c
@@ -1,4 +1,5 @@
-/* © 2004-2007 Anselm R. Garbe <garbeam at gmail dot com>
+/* © 2006-2007 Anselm R. Garbe <garbeam at gmail dot com>
+ * © 2006-2007 Sander van Dijk <a dot h dot vandijk at gmail dot com>
  * See LICENSE file for license details. */
 #include "dwm.h"
 #include <stdlib.h>
@@ -14,7 +15,7 @@ static unsigned int nmaster = NMASTER;
 
 static void
 tile(void) {
-       unsigned int i, n, nx, ny, nw, nh, mw, mh, tw, th;
+       unsigned int i, n, nx, ny, nw, nh, mw, mh, tw, th, remainder;
        Client *c;
 
        for(n = 0, c = nexttiled(clients); c; c = nexttiled(c->next))
@@ -23,6 +24,7 @@ tile(void) {
        mh = (n > nmaster) ? wah / nmaster : wah / (n > 0 ? n : 1);
        mw = (n > nmaster) ? (waw * masterw) / 1000 : waw;
        th = (n > nmaster) ? wah / (n - nmaster) : 0;
+       remainder = (n > nmaster) ? wah - th * (n - nmaster) : 0;
        tw = waw - mw;
 
        for(i = 0, c = clients; c; c = c->next)
@@ -37,18 +39,20 @@ tile(void) {
                        ny = way;
                        if(i < nmaster) {
                                ny += i * mh;
-                               nw = mw - 2 * BORDERPX;
-                               nh = mh - 2 * BORDERPX;
+                               nw = mw - 2 * c->border;
+                               nh = mh - 2 * c->border;
                        }
                        else {  /* tile window */
                                nx += mw;
-                               nw = tw - 2 * BORDERPX;
-                               if(th > 2 * BORDERPX) {
+                               nw = tw - 2 * c->border;
+                               if(th > 2 * c->border) {
                                        ny += (i - nmaster) * th;
-                                       nh = th - 2 * BORDERPX;
+                                       nh = th - 2 * c->border;
+                                       if (i == n - 1)
+                                               nh += remainder;
                                }
-                               else /* fallback if th <= 2 * BORDERPX */
-                                       nh = wah - 2 * BORDERPX;
+                               else /* fallback if th <= 2 * c->border */
+                                       nh = wah - 2 * c->border;
                        }
                        resize(c, nx, ny, nw, nh, False);
                        i++;
@@ -124,7 +128,7 @@ incmasterw(const char *arg) {
                masterw = MASTERWIDTH;
        else {
                i = atoi(arg);
-               if(waw * (masterw + i) / 1000 >= waw - 2 * BORDERPX
+               if(waw * (masterw + i) / 1000 >= waw - 2 * BORDERPX 
                || waw * (masterw + i) / 1000 <= 2 * BORDERPX)
                        return;
                masterw += i;